@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2021 The Octave Project Developers
+// Copyright (C) 1993-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -48,6 +48,8 @@ set_output_prec (int prec)
   Voutput_precision = prec;
 }
 
+OCTAVE_NAMESPACE_BEGIN
+
 DEFUN (output_precision, args, nargout,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{val} =} output_precision ()
@@ -67,5 +69,8 @@ The original variable value is restored when exiting the function.
 @seealso{format, fixed_point_format}
 @end deftypefn */)
 {
-  return SET_INTERNAL_VARIABLE_WITH_LIMITS (output_precision, 0, 16);
+  return set_internal_variable (Voutput_precision, args, nargout,
+                                "output_precision", 0, 16);
 }
+
+OCTAVE_NAMESPACE_END
