@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2004-2021 The Octave Project Developers
+// Copyright (C) 2004-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -62,7 +62,7 @@ octave_hdf5_id octave_int32_scalar::hdf5_save_type = HDF5_SAVE_TYPE;
 // Prevent implicit instantiations on some systems (Windows, others?)
 // that can lead to duplicate definitions of static data members.
 
-extern template class OCTINTERP_API octave_base_scalar<double>;
+extern template class octave_base_scalar<double>;
 
 template class octave_base_matrix<int32NDArray>;
 
