@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 1994-2018 John W. Eaton
-Copyright (C) 2009 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1994-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -27,11 +29,23 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "error.h"
 #include "ovl.h"
-#include "Cell.h"
 
 // We are likely to have a lot of octave_value_list objects to allocate,
 // so make the grow_size large.
 
+octave_value_list::octave_value_list (const std::list<octave_value>& lst)
+{
+  std::size_t nel = lst.size ();
+
+  if (nel > 0)
+    {
+      m_data.resize (nel);
+      octave_idx_type k = 0;
+      for (const auto& ov : lst)
+        m_data[k++] = ov;
+    }
+}
+
 octave_value_list::octave_value_list (const std::list<octave_value_list>& lst)
 {
   octave_idx_type n = 0;
@@ -46,16 +60,17 @@ octave_value_list::octave_value_list (const std::list<octave_value_list>& lst)
 
   // Optimize single-element case
   if (n == 1)
-    data = lst.front ().data;
+    m_data = lst.front ().m_data;
   else if (nel > 0)
     {
-      data.resize (dim_vector (1, nel));
+      m_data.resize (nel);
       octave_idx_type k = 0;
       for (const auto& ovl : lst)
         {
-          data.assign (idx_vector (k, k + ovl.length ()), ovl.data);
-          k += ovl.length ();
+          for (octave_idx_type i = 0; i < ovl.length (); i++)
+            m_data[k++] = ovl(i);
         }
+
       assert (k == nel);
     }
 
@@ -262,13 +277,13 @@ void
 octave_value_list::make_storable_values (void)
 {
   octave_idx_type len = length ();
-  const Array<octave_value>& cdata = data;
+  const std::vector<octave_value>& cdata = m_data;
 
   for (octave_idx_type i = 0; i < len; i++)
     {
       // This is optimized so that we don't force a copy unless necessary.
-      octave_value tmp = cdata(i).storable_value ();
-      if (! tmp.is_copy_of (cdata (i)))
-        data(i) = tmp;
+      octave_value tmp = cdata[i].storable_value ();
+      if (! tmp.is_copy_of (cdata[i]))
+        m_data[i] = tmp;
     }
 }
