@@ -34,7 +34,7 @@
 
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1995-2020 The Octave Project Developers
+// Copyright (C) 1995-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -63,6 +63,7 @@
 
 enum octave_kw_id
 {
+  arguments_kw,
   break_kw,
   case_kw,
   catch_kw,
@@ -74,6 +75,7 @@ enum octave_kw_id
   end_kw,
   end_try_catch_kw,
   end_unwind_protect_kw,
+  endarguments_kw,
   endclassdef_kw,
   endenumeration_kw,
   endevents_kw,
@@ -83,6 +85,7 @@ enum octave_kw_id
   endmethods_kw,
   endparfor_kw,
   endproperties_kw,
+  endspmd_kw,
   endswitch_kw,
   endwhile_kw,
   enumeration_kw,
@@ -101,6 +104,7 @@ enum octave_kw_id
   properties_kw,
   return_kw,
   set_kw,
+  spmd_kw,
   switch_kw,
   try_kw,
   until_kw,
@@ -109,15 +113,15 @@ enum octave_kw_id
   while_kw
 };
 
-#line 82 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+#line 86 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
 struct octave_kw { const char *name; int tok; octave_kw_id kw_id; };
 
-#define TOTAL_KEYWORDS 44
+#define TOTAL_KEYWORDS 48
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 22
 #define MIN_HASH_VALUE 2
-#define MAX_HASH_VALUE 68
-/* maximum key range = 67, duplicates = 0 */
+#define MAX_HASH_VALUE 71
+/* maximum key range = 70, duplicates = 0 */
 
 class octave_kw_hash
 {
@@ -132,32 +136,32 @@ octave_kw_hash::hash (const char *str, size_t len)
 {
   static const unsigned char asso_values[] =
     {
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 55, 69,  5, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69,  5, 69, 50,  0,  5,
-       0,  0, 45,  5, 50, 15, 69,  0, 25,  0,
-       0, 20,  5, 69, 25, 30, 10, 35, 10, 15,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69, 69, 69, 69, 69,
-      69, 69, 69, 69, 69, 69
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 55, 72,  5, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72,  5, 72, 25,  0, 10,
+       0,  0, 30, 40, 50, 30, 72,  0, 30,  5,
+      10, 10, 10, 72,  0,  5, 25, 35, 35, 20,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72, 72, 72, 72, 72,
+      72, 72, 72, 72, 72, 72
     };
   unsigned int hval = len;
 
@@ -178,103 +182,112 @@ octave_kw_hash::hash (const char *str, size_t len)
 
 static const struct octave_kw wordlist[] =
   {
-#line 90 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"do", DO, do_kw},
-#line 93 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"end", END, end_kw},
-#line 91 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"else", ELSE, else_kw},
-#line 85 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"break", BREAK, break_kw},
-#line 111 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"get", GET, get_kw},
-#line 86 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"case", CASE, case_kw},
-#line 102 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endmethods", END, endmethods_kw},
-#line 107 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"enumeration", ENUMERATION, enumeration_kw},
-#line 122 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"try", TRY, try_kw},
-#line 97 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endenumeration", END, endenumeration_kw},
-#line 118 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"properties", PROPERTIES, properties_kw},
-#line 108 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"events", EVENTS, events_kw},
-#line 113 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"if", IF, if_kw},
-#line 128 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"__LINE__", NUM, magic_line_kw},
-#line 98 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endevents", END, endevents_kw},
-#line 126 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"while", WHILE, while_kw},
-#line 92 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"elseif", ELSEIF, elseif_kw},
-#line 94 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"end_try_catch", END, end_try_catch_kw},
-#line 105 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endswitch", END, endswitch_kw},
-#line 99 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endfor", END, endfor_kw},
-#line 114 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"methods", METHODS, methods_kw},
-#line 89 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"continue", CONTINUE, continue_kw},
-#line 117 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"persistent", PERSISTENT, persistent_kw},
-#line 116 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"parfor", PARFOR, parfor_kw},
-#line 120 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"set", SET, set_kw},
-#line 96 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endclassdef", END, endclassdef_kw},
-#line 104 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endproperties", END, endproperties_kw},
-#line 121 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"switch", SWITCH, switch_kw},
-#line 88 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"classdef", CLASSDEF, classdef_kw},
-#line 100 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endfunction", END, endfunction_kw},
-#line 109 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"for", FOR, for_kw},
-#line 124 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"unwind_protect", UNWIND, unwind_protect_kw},
-#line 101 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endif", END, endif_kw},
 #line 95 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"end_unwind_protect", END, end_unwind_protect_kw},
-#line 115 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"otherwise", OTHERWISE, otherwise_kw},
-#line 119 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"do", DO, do_kw},
+#line 98 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"end", END, end_kw},
+#line 96 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"else", ELSE, else_kw},
+#line 90 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"break", BREAK, break_kw},
+#line 126 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
     {"return", FUNC_RET, return_kw},
-#line 125 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"unwind_protect_cleanup", CLEANUP, unwind_protect_cleanup_kw},
-#line 106 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endwhile", END, endwhile_kw},
-#line 103 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"endparfor", END, endparfor_kw},
-#line 87 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"catch", CATCH, catch_kw},
-#line 112 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"global", GLOBAL, global_kw},
-#line 110 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"function", FCN, function_kw},
-#line 123 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"until", UNTIL, until_kw},
 #line 127 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
-    {"__FILE__", DQ_STRING, magic_file_kw}
+    {"set", SET, set_kw},
+#line 128 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"spmd", SPMD, spmd_kw},
+#line 108 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endmethods", END, endmethods_kw},
+#line 114 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"enumeration", ENUMERATION, enumeration_kw},
+#line 101 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endarguments", END, endarguments_kw},
+#line 110 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endproperties", END, endproperties_kw},
+#line 91 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"case", CASE, case_kw},
+#line 105 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endfor", END, endfor_kw},
+#line 111 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endspmd", END, endspmd_kw},
+#line 136 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"__LINE__", NUMBER, magic_line_kw},
+#line 122 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"otherwise", OTHERWISE, otherwise_kw},
+#line 125 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"properties", PROPERTIES, properties_kw},
+#line 129 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"switch", SWITCH, switch_kw},
+#line 121 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"methods", METHODS, methods_kw},
+#line 93 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"classdef", CLASSDEF, classdef_kw},
+#line 103 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endenumeration", END, endenumeration_kw},
+#line 134 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"while", WHILE, while_kw},
+#line 123 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"parfor", PARFOR, parfor_kw},
+#line 130 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"try", TRY, try_kw},
+#line 112 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endswitch", END, endswitch_kw},
+#line 115 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"events", EVENTS, events_kw},
+#line 120 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"if", IF, if_kw},
+#line 116 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"for", FOR, for_kw},
+#line 109 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endparfor", END, endparfor_kw},
+#line 107 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endif", END, endif_kw},
+#line 97 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"elseif", ELSEIF, elseif_kw},
+#line 99 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"end_try_catch", END, end_try_catch_kw},
+#line 89 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"arguments", ARGUMENTS, arguments_kw},
+#line 102 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endclassdef", END, endclassdef_kw},
+#line 118 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"get", GET, get_kw},
+#line 104 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endevents", END, endevents_kw},
+#line 106 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endfunction", END, endfunction_kw},
+#line 94 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"continue", CONTINUE, continue_kw},
+#line 124 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"persistent", PERSISTENT, persistent_kw},
+#line 100 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"end_unwind_protect", END, end_unwind_protect_kw},
+#line 113 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"endwhile", END, endwhile_kw},
+#line 132 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"unwind_protect", UNWIND, unwind_protect_kw},
+#line 117 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"function", FCN, function_kw},
+#line 92 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"catch", CATCH, catch_kw},
+#line 133 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"unwind_protect_cleanup", CLEANUP, unwind_protect_cleanup_kw},
+#line 135 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"__FILE__", DQ_STRING, magic_file_kw},
+#line 131 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"until", UNTIL, until_kw},
+#line 119 "/home/jwe/src/octave-stable/libinterp/parse-tree/octave.gperf"
+    {"global", GLOBAL, global_kw}
   };
 
 static const signed char gperf_lookup[] =
   {
-    -1, -1,  0,  1,  2,  3, -1, -1,  4,  5,  6,  7, -1,  8,
-     9, 10, 11, 12, 13, 14, 15, 16, -1, 17, 18, -1, 19, 20,
-    21, -1, 22, 23, -1, 24, -1, -1, 25, -1, 26, -1, -1, 27,
-    -1, 28, -1, -1, 29, -1, 30, 31, 32, -1, -1, 33, 34, -1,
-    35, 36, 37, 38, 39, 40, -1, 41, -1, 42, -1, -1, 43
+    -1, -1,  0,  1,  2,  3,  4, -1,  5,  6,  7,  8,  9, 10,
+    11, -1, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, -1,
+    23, 24, -1, 25, 26, 27, 28, 29, 30, -1, 31, 32, -1, 33,
+    -1, 34, 35, -1, 36, -1, 37, -1, 38, -1, -1, 39, -1, -1,
+    -1, -1, 40, 41, -1, -1, -1, 42, -1, 43, -1, 44, 45, -1,
+    46, 47
   };
 
 const struct octave_kw *
