@@ -1,140 +1,128 @@
-/*
-
-Copyright (C) 1996-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include <cfloat>
-
+#include <cinttypes>
 #include <sstream>
 
 #include "DASPK.h"
+#include "dMatrix.h"
 #include "f77-fcn.h"
 #include "lo-error.h"
-#include "lo-math.h"
 #include "quit.h"
 
-typedef octave_idx_type (*daspk_fcn_ptr) (const double&, const double*,
-                                          const double*, const double&,
-                                          double*, octave_idx_type&,
-                                          double*, octave_idx_type*);
+typedef F77_INT (*daspk_fcn_ptr) (const double&, const double *, const double *,
+                                  const double&, double *, F77_INT&, double *,
+                                  F77_INT *);
 
-typedef octave_idx_type (*daspk_jac_ptr) (const double&, const double*,
-                                          const double*, double*,
-                                          const double&, double*,
-                                          octave_idx_type*);
+typedef F77_INT (*daspk_jac_ptr) (const double&, const double *, const double *,
+                                  double *, const double&, double *, F77_INT *);
 
-typedef octave_idx_type (*daspk_psol_ptr) (const octave_idx_type&,
-                                           const double&, const double*,
-                                           const double*, const double*,
-                                           const double&, const double*,
-                                           double*, octave_idx_type*,
-                                           double*, const double&,
-                                           octave_idx_type&, double*,
-                                           octave_idx_type*);
+typedef F77_INT (*daspk_psol_ptr) (const F77_INT&, const double&,
+                                   const double *, const double *,
+                                   const double *, const double&,
+                                   const double *, double *, F77_INT *,
+                                   double *, const double&, F77_INT&,
+                                   double *, F77_INT *);
 
 extern "C"
 {
   F77_RET_T
-  F77_FUNC (ddaspk, DDASPK) (daspk_fcn_ptr, const F77_INT&,
-                             F77_DBLE&, F77_DBLE*, F77_DBLE*, F77_DBLE&,
-                             const F77_INT*, const F77_DBLE*,
-                             const F77_DBLE*, F77_INT&,
-                             F77_DBLE*, const F77_INT&,
-                             F77_INT*, const F77_INT&,
-                             const F77_DBLE*, const F77_INT*,
+  F77_FUNC (ddaspk, DDASPK) (daspk_fcn_ptr, const F77_INT&, F77_DBLE&,
+                             F77_DBLE *, F77_DBLE *, F77_DBLE&, const F77_INT *,
+                             const F77_DBLE *, const F77_DBLE *, F77_INT&,
+                             F77_DBLE *, const F77_INT&, F77_INT *,
+                             const F77_INT&, const F77_DBLE *, const F77_INT *,
                              daspk_jac_ptr, daspk_psol_ptr);
 }
 
 static DAEFunc::DAERHSFunc user_fun;
 static DAEFunc::DAEJacFunc user_jac;
-static octave_idx_type nn;
+static F77_INT nn;
 
-static octave_idx_type
+static F77_INT
 ddaspk_f (const double& time, const double *state, const double *deriv,
-          const double&, double *delta, octave_idx_type& ires, double *,
-          octave_idx_type *)
+          const double&, double *delta, F77_INT& ires, double *, F77_INT *)
 {
-  BEGIN_INTERRUPT_WITH_EXCEPTIONS;
-
   ColumnVector tmp_deriv (nn);
   ColumnVector tmp_state (nn);
   ColumnVector tmp_delta (nn);
 
-  for (octave_idx_type i = 0; i < nn; i++)
+  for (F77_INT i = 0; i < nn; i++)
     {
       tmp_deriv.elem (i) = deriv[i];
       tmp_state.elem (i) = state[i];
     }
 
-  tmp_delta = user_fun (tmp_state, tmp_deriv, time, ires);
+  octave_idx_type tmp_ires = ires;
+
+  tmp_delta = user_fun (tmp_state, tmp_deriv, time, tmp_ires);
+
+  ires = octave::to_f77_int (tmp_ires);
 
   if (ires >= 0)
     {
-      if (tmp_delta.is_empty ())
+      if (tmp_delta.isempty ())
         ires = -2;
       else
         {
-          for (octave_idx_type i = 0; i < nn; i++)
+          for (F77_INT i = 0; i < nn; i++)
             delta[i] = tmp_delta.elem (i);
         }
     }
 
-  END_INTERRUPT_WITH_EXCEPTIONS;
-
   return 0;
 }
 
 //NEQ, T, Y, YPRIME, SAVR, WK, CJ, WGHT,
 //C                          WP, IWP, B, EPLIN, IER, RPAR, IPAR)
 
-static octave_idx_type
-ddaspk_psol (const octave_idx_type&, const double&, const double *,
+static F77_INT
+ddaspk_psol (const F77_INT&, const double&, const double *,
              const double *, const double *, const double&,
-             const double *, double *, octave_idx_type *, double *,
-             const double&, octave_idx_type&, double *, octave_idx_type*)
+             const double *, double *, F77_INT *, double *,
+             const double&, F77_INT&, double *, F77_INT *)
 {
-  BEGIN_INTERRUPT_WITH_EXCEPTIONS;
-
-  abort ();
-
-  END_INTERRUPT_WITH_EXCEPTIONS;
+  (*current_liboctave_error_handler) ("daspk: PSOL is not implemented");
 
   return 0;
 }
 
-static octave_idx_type
+static F77_INT
 ddaspk_j (const double& time, const double *state, const double *deriv,
-          double *pd, const double& cj, double *, octave_idx_type *)
+          double *pd, const double& cj, double *, F77_INT *)
 {
-  BEGIN_INTERRUPT_WITH_EXCEPTIONS;
-
   // FIXME: would be nice to avoid copying the data.
 
   ColumnVector tmp_state (nn);
   ColumnVector tmp_deriv (nn);
 
-  for (octave_idx_type i = 0; i < nn; i++)
+  for (F77_INT i = 0; i < nn; i++)
     {
       tmp_deriv.elem (i) = deriv[i];
       tmp_state.elem (i) = state[i];
@@ -142,47 +130,45 @@ ddaspk_j (const double& time, const double *state, const double *deriv,
 
   Matrix tmp_pd = user_jac (tmp_state, tmp_deriv, time, cj);
 
-  for (octave_idx_type j = 0; j < nn; j++)
-    for (octave_idx_type i = 0; i < nn; i++)
+  for (F77_INT j = 0; j < nn; j++)
+    for (F77_INT i = 0; i < nn; i++)
       pd[nn * j + i] = tmp_pd.elem (i, j);
 
-  END_INTERRUPT_WITH_EXCEPTIONS;
-
   return 0;
 }
 
 ColumnVector
 DASPK::do_integrate (double tout)
 {
-  // FIXME: should handle all this option stuff just once
-  // for each new problem.
+  // FIXME: should handle all this option stuff just once for each new problem.
 
   ColumnVector retval;
 
-  if (! initialized || restart || DAEFunc::reset || DASPK_options::reset)
+  if (! m_initialized || m_restart || DAEFunc::m_reset
+      || DASPK_options::m_reset)
     {
-      integration_error = false;
+      m_integration_error = false;
 
-      initialized = true;
+      m_initialized = true;
 
-      info.resize (dim_vector (20, 1));
+      m_info.resize (dim_vector (20, 1));
 
-      for (octave_idx_type i = 0; i < 20; i++)
-        info(i) = 0;
+      for (F77_INT i = 0; i < 20; i++)
+        m_info(i) = 0;
 
-      octave_idx_type n = size ();
+      F77_INT n = octave::to_f77_int (size ());
 
       nn = n;
 
-      info(0) = 0;
+      m_info(0) = 0;
 
-      if (stop_time_set)
+      if (m_stop_time_set)
         {
-          rwork(0) = stop_time;
-          info(3) = 1;
+          m_rwork(0) = m_stop_time;
+          m_info(3) = 1;
         }
       else
-        info(3) = 0;
+        m_info(3) = 0;
 
       // DAEFunc
 
@@ -193,15 +179,15 @@ DASPK::do_integrate (double tout)
         {
           octave_idx_type ires = 0;
 
-          ColumnVector res = (*user_fun) (x, xdot, t, ires);
+          ColumnVector res = (*user_fun) (m_x, m_xdot, m_t, ires);
 
-          if (res.numel () != x.numel ())
+          if (res.numel () != m_x.numel ())
             {
               // FIXME: Should this be a warning?
               (*current_liboctave_error_handler)
                 ("daspk: inconsistent sizes for state and residual vectors");
 
-              integration_error = true;
+              m_integration_error = true;
               return retval;
             }
         }
@@ -211,90 +197,89 @@ DASPK::do_integrate (double tout)
           (*current_liboctave_error_handler)
             ("daspk: no user supplied RHS subroutine!");
 
-          integration_error = true;
+          m_integration_error = true;
           return retval;
         }
 
-      info(4) = user_jac ? 1 : 0;
+      m_info(4) = (user_jac ? 1 : 0);
 
-      DAEFunc::reset = false;
+      DAEFunc::m_reset = false;
 
       octave_idx_type eiq = enforce_inequality_constraints ();
       octave_idx_type ccic = compute_consistent_initial_condition ();
       octave_idx_type eavfet = exclude_algebraic_variables_from_error_test ();
 
-      liw = 40 + n;
+      m_liw = 40 + n;
       if (eiq == 1 || eiq == 3)
-        liw += n;
+        m_liw += n;
       if (ccic == 1 || eavfet == 1)
-        liw += n;
+        m_liw += n;
 
-      lrw = 50 + 9*n + n*n;
+      m_lrw = 50 + 9*n + n*n;
       if (eavfet == 1)
-        lrw += n;
+        m_lrw += n;
 
-      iwork.resize (dim_vector (liw, 1));
-      rwork.resize (dim_vector (lrw, 1));
+      m_iwork.resize (dim_vector (m_liw, 1));
+      m_rwork.resize (dim_vector (m_lrw, 1));
 
       // DASPK_options
 
-      abs_tol = absolute_tolerance ();
-      rel_tol = relative_tolerance ();
+      m_abs_tol = absolute_tolerance ();
+      m_rel_tol = relative_tolerance ();
 
-      octave_idx_type abs_tol_len = abs_tol.numel ();
-      octave_idx_type rel_tol_len = rel_tol.numel ();
+      F77_INT abs_tol_len = octave::to_f77_int (m_abs_tol.numel ());
+      F77_INT rel_tol_len = octave::to_f77_int (m_rel_tol.numel ());
 
       if (abs_tol_len == 1 && rel_tol_len == 1)
         {
-          info(1) = 0;
+          m_info(1) = 0;
         }
       else if (abs_tol_len == n && rel_tol_len == n)
         {
-          info(1) = 1;
+          m_info(1) = 1;
         }
       else
         {
-
           // FIXME: Should this be a warning?
           (*current_liboctave_error_handler)
             ("daspk: inconsistent sizes for tolerance arrays");
 
-          integration_error = true;
+          m_integration_error = true;
           return retval;
         }
 
       double hmax = maximum_step_size ();
       if (hmax >= 0.0)
         {
-          rwork(1) = hmax;
-          info(6) = 1;
+          m_rwork(1) = hmax;
+          m_info(6) = 1;
         }
       else
-        info(6) = 0;
+        m_info(6) = 0;
 
       double h0 = initial_step_size ();
       if (h0 >= 0.0)
         {
-          rwork(2) = h0;
-          info(7) = 1;
+          m_rwork(2) = h0;
+          m_info(7) = 1;
         }
       else
-        info(7) = 0;
+        m_info(7) = 0;
 
       octave_idx_type maxord = maximum_order ();
       if (maxord >= 0)
         {
           if (maxord > 0 && maxord < 6)
             {
-              info(8) = 1;
-              iwork(2) = maxord;
+              m_info(8) = 1;
+              m_iwork(2) = octave::to_f77_int (maxord);
             }
           else
             {
               // FIXME: Should this be a warning?
               (*current_liboctave_error_handler)
                 ("daspk: invalid value for maximum order");
-              integration_error = true;
+              m_integration_error = true;
               return retval;
             }
         }
@@ -306,20 +291,22 @@ DASPK::do_integrate (double tout)
           {
             Array<octave_idx_type> ict = inequality_constraint_types ();
 
-            if (ict.numel () == n)
+            F77_INT ict_nel = octave::to_f77_int (ict.numel ());
+
+            if (ict_nel == n)
               {
-                for (octave_idx_type i = 0; i < n; i++)
+                for (F77_INT i = 0; i < n; i++)
                   {
-                    octave_idx_type val = ict(i);
+                    F77_INT val = octave::to_f77_int (ict(i));
                     if (val < -2 || val > 2)
                       {
                         // FIXME: Should this be a warning?
                         (*current_liboctave_error_handler)
                           ("daspk: invalid value for inequality constraint type");
-                        integration_error = true;
+                        m_integration_error = true;
                         return retval;
                       }
-                    iwork(40+i) = val;
+                    m_iwork(40+i) = val;
                   }
               }
             else
@@ -327,22 +314,22 @@ DASPK::do_integrate (double tout)
                 // FIXME: Should this be a warning?
                 (*current_liboctave_error_handler)
                   ("daspk: inequality constraint types size mismatch");
-                integration_error = true;
+                m_integration_error = true;
                 return retval;
               }
           }
-        // Fall through...
+          OCTAVE_FALLTHROUGH;
 
         case 0:
         case 2:
-          info(9) = eiq;
+          m_info(9) = octave::to_f77_int (eiq);
           break;
 
         default:
           // FIXME: Should this be a warning?
           (*current_liboctave_error_handler)
             ("daspk: invalid value for enforce inequality constraints option");
-          integration_error = true;
+          m_integration_error = true;
           return retval;
         }
 
@@ -354,25 +341,29 @@ DASPK::do_integrate (double tout)
 
               Array<octave_idx_type> av = algebraic_variables ();
 
-              if (av.numel () == n)
+              F77_INT av_nel = octave::to_f77_int (av.numel ());
+
+              if (av_nel == n)
                 {
-                  octave_idx_type lid;
+                  F77_INT lid;
                   if (eiq == 0 || eiq == 2)
                     lid = 40;
                   else if (eiq == 1 || eiq == 3)
                     lid = 40 + n;
                   else
-                    abort ();
+                    (*current_liboctave_error_handler)
+                      ("daspk: invalid value for eiq: "
+                       "%" OCTAVE_IDX_TYPE_FORMAT, eiq);
 
-                  for (octave_idx_type i = 0; i < n; i++)
-                    iwork(lid+i) = av(i) ? -1 : 1;
+                  for (F77_INT i = 0; i < n; i++)
+                    m_iwork(lid+i) = (av(i) ? -1 : 1);
                 }
               else
                 {
                   // FIXME: Should this be a warning?
                   (*current_liboctave_error_handler)
                     ("daspk: algebraic variables size mismatch");
-                  integration_error = true;
+                  m_integration_error = true;
                   return retval;
                 }
             }
@@ -381,33 +372,37 @@ DASPK::do_integrate (double tout)
               // FIXME: Should this be a warning?
               (*current_liboctave_error_handler)
                 ("daspk: invalid value for compute consistent initial condition option");
-              integration_error = true;
+              m_integration_error = true;
               return retval;
             }
 
-          info(10) = ccic;
+          m_info(10) = octave::to_f77_int (ccic);
         }
 
       if (eavfet)
         {
-          info(15) = 1;
+          m_info(15) = 1;
 
           // FIXME: this code is duplicated above.
 
           Array<octave_idx_type> av = algebraic_variables ();
 
-          if (av.numel () == n)
+          F77_INT av_nel = octave::to_f77_int (av.numel ());
+
+          if (av_nel == n)
             {
-              octave_idx_type lid;
+              F77_INT lid;
               if (eiq == 0 || eiq == 2)
                 lid = 40;
               else if (eiq == 1 || eiq == 3)
                 lid = 40 + n;
               else
-                abort ();
+                (*current_liboctave_error_handler)
+                  ("daspk: invalid value for eiq: %" OCTAVE_IDX_TYPE_FORMAT,
+                   eiq);
 
-              for (octave_idx_type i = 0; i < n; i++)
-                iwork(lid+i) = av(i) ? -1 : 1;
+              for (F77_INT i = 0; i < n; i++)
+                m_iwork(lid+i) = (av(i) ? -1 : 1);
             }
         }
 
@@ -417,24 +412,24 @@ DASPK::do_integrate (double tout)
 
           if (ich.numel () == 6)
             {
-              iwork(31) = octave::math::nint_big (ich(0));
-              iwork(32) = octave::math::nint_big (ich(1));
-              iwork(33) = octave::math::nint_big (ich(2));
-              iwork(34) = octave::math::nint_big (ich(3));
+              m_iwork(31) = octave::to_f77_int (octave::math::nint_big (ich(0)));
+              m_iwork(32) = octave::to_f77_int (octave::math::nint_big (ich(1)));
+              m_iwork(33) = octave::to_f77_int (octave::math::nint_big (ich(2)));
+              m_iwork(34) = octave::to_f77_int (octave::math::nint_big (ich(3)));
 
-              rwork(13) = ich(4);
-              rwork(14) = ich(5);
+              m_rwork(13) = ich(4);
+              m_rwork(14) = ich(5);
             }
           else
             {
               // FIXME: Should this be a warning?
               (*current_liboctave_error_handler)
                 ("daspk: invalid initial condition heuristics option");
-              integration_error = true;
+              m_integration_error = true;
               return retval;
             }
 
-          info(16) = 1;
+          m_info(16) = 1;
         }
 
       octave_idx_type pici = print_initial_condition_info ();
@@ -443,43 +438,47 @@ DASPK::do_integrate (double tout)
         case 0:
         case 1:
         case 2:
-          info(17) = pici;
+          m_info(17) = octave::to_f77_int (pici);
           break;
 
         default:
           // FIXME: Should this be a warning?
           (*current_liboctave_error_handler)
             ("daspk: invalid value for print initial condition info option");
-          integration_error = true;
+          m_integration_error = true;
           return retval;
           break;
         }
 
-      DASPK_options::reset = false;
+      DASPK_options::m_reset = false;
 
-      restart = false;
+      m_restart = false;
     }
 
-  double *px = x.fortran_vec ();
-  double *pxdot = xdot.fortran_vec ();
+  double *px = m_x.fortran_vec ();
+  double *pxdot = m_xdot.fortran_vec ();
 
-  octave_idx_type *pinfo = info.fortran_vec ();
+  F77_INT *pinfo = m_info.fortran_vec ();
 
-  double *prel_tol = rel_tol.fortran_vec ();
-  double *pabs_tol = abs_tol.fortran_vec ();
+  double *prel_tol = m_rel_tol.fortran_vec ();
+  double *pabs_tol = m_abs_tol.fortran_vec ();
 
-  double *prwork = rwork.fortran_vec ();
-  octave_idx_type *piwork = iwork.fortran_vec ();
+  double *prwork = m_rwork.fortran_vec ();
+  F77_INT *piwork = m_iwork.fortran_vec ();
 
-  double *dummy = 0;
-  octave_idx_type *idummy = 0;
+  double *dummy = nullptr;
+  F77_INT *idummy = nullptr;
 
-  F77_XFCN (ddaspk, DDASPK, (ddaspk_f, nn, t, px, pxdot, tout, pinfo,
-                             prel_tol, pabs_tol, istate, prwork, lrw,
-                             piwork, liw, dummy, idummy, ddaspk_j,
+  F77_INT tmp_istate = octave::to_f77_int (m_istate);
+
+  F77_XFCN (ddaspk, DDASPK, (ddaspk_f, nn, m_t, px, pxdot, tout, pinfo,
+                             prel_tol, pabs_tol, tmp_istate, prwork, m_lrw,
+                             piwork, m_liw, dummy, idummy, ddaspk_j,
                              ddaspk_psol));
 
-  switch (istate)
+  m_istate = tmp_istate;
+
+  switch (m_istate)
     {
     case 1: // A step was successfully taken in intermediate-output
             // mode.  The code has not yet reached TOUT.
@@ -492,8 +491,8 @@ DASPK::do_integrate (double tout)
             // INFO(11) > 0, was successful, and INFO(14) = 1.
             // No integration steps were taken, and the solution
             // is not considered to have been started.
-      retval = x;
-      t = tout;
+      retval = m_x;
+      m_t = tout;
       break;
 
     case -1: // A large amount of work has been expended.  (~500 steps).
@@ -520,16 +519,17 @@ DASPK::do_integrate (double tout)
     case -14: // The Krylov linear system solver could not
               // achieve convergence.
     case -33: // The code has encountered trouble from which it cannot
-              // recover. A message is printed explaining the trouble
+              // recover.  A message is printed explaining the trouble
               // and control is returned to the calling program.  For
               // example, this occurs when invalid input is detected.
-      integration_error = true;
+      m_integration_error = true;
       break;
 
     default:
-      integration_error = true;
+      m_integration_error = true;
       (*current_liboctave_error_handler)
-        ("unrecognized value of istate (= %d) returned from ddaspk", istate);
+        ("unrecognized value of m_istate (= %" OCTAVE_IDX_TYPE_FORMAT ") "
+         "returned from ddaspk", m_istate);
       break;
     }
 
@@ -549,30 +549,30 @@ DASPK::integrate (const ColumnVector& tout, Matrix& xdot_out)
   Matrix retval;
 
   octave_idx_type n_out = tout.numel ();
-  octave_idx_type n = size ();
+  F77_INT n = octave::to_f77_int (size ());
 
   if (n_out > 0 && n > 0)
     {
       retval.resize (n_out, n);
       xdot_out.resize (n_out, n);
 
-      for (octave_idx_type i = 0; i < n; i++)
+      for (F77_INT i = 0; i < n; i++)
         {
-          retval.elem (0, i) = x.elem (i);
-          xdot_out.elem (0, i) = xdot.elem (i);
+          retval.elem (0, i) = m_x.elem (i);
+          xdot_out.elem (0, i) = m_xdot.elem (i);
         }
 
       for (octave_idx_type j = 1; j < n_out; j++)
         {
           ColumnVector x_next = do_integrate (tout.elem (j));
 
-          if (integration_error)
+          if (m_integration_error)
             return retval;
 
-          for (octave_idx_type i = 0; i < n; i++)
+          for (F77_INT i = 0; i < n; i++)
             {
               retval.elem (j, i) = x_next.elem (i);
-              xdot_out.elem (j, i) = xdot.elem (i);
+              xdot_out.elem (j, i) = m_xdot.elem (i);
             }
         }
     }
@@ -594,17 +594,17 @@ DASPK::integrate (const ColumnVector& tout, Matrix& xdot_out,
   Matrix retval;
 
   octave_idx_type n_out = tout.numel ();
-  octave_idx_type n = size ();
+  F77_INT n = octave::to_f77_int (size ());
 
   if (n_out > 0 && n > 0)
     {
       retval.resize (n_out, n);
       xdot_out.resize (n_out, n);
 
-      for (octave_idx_type i = 0; i < n; i++)
+      for (F77_INT i = 0; i < n; i++)
         {
-          retval.elem (0, i) = x.elem (i);
-          xdot_out.elem (0, i) = xdot.elem (i);
+          retval.elem (0, i) = m_x.elem (i);
+          xdot_out.elem (0, i) = m_xdot.elem (i);
         }
 
       octave_idx_type n_crit = tcrit.numel ();
@@ -663,15 +663,15 @@ DASPK::integrate (const ColumnVector& tout, Matrix& xdot_out,
 
               ColumnVector x_next = do_integrate (t_out);
 
-              if (integration_error)
+              if (m_integration_error)
                 return retval;
 
               if (save_output)
                 {
-                  for (octave_idx_type i = 0; i < n; i++)
+                  for (F77_INT i = 0; i < n; i++)
                     {
                       retval.elem (i_out-1, i) = x_next.elem (i);
-                      xdot_out.elem (i_out-1, i) = xdot.elem (i);
+                      xdot_out.elem (i_out-1, i) = m_xdot.elem (i);
                     }
                 }
 
@@ -683,7 +683,7 @@ DASPK::integrate (const ColumnVector& tout, Matrix& xdot_out,
         {
           retval = integrate (tout, xdot_out);
 
-          if (integration_error)
+          if (m_integration_error)
             return retval;
         }
     }
@@ -697,10 +697,10 @@ DASPK::error_message (void) const
   std::string retval;
 
   std::ostringstream buf;
-  buf << t;
+  buf << m_t;
   std::string t_curr = buf.str ();
 
-  switch (istate)
+  switch (m_istate)
     {
     case 1:
       retval = "a step was successfully taken in intermediate-output mode.";
@@ -719,8 +719,7 @@ DASPK::error_message (void) const
       break;
 
     case -1:
-      retval = std::string ("a large amount of work has been expended (t =")
-               + t_curr + ")";
+      retval = "a large amount of work has been expended (t =" + t_curr + ')';
       break;
 
     case -2:
@@ -728,39 +727,37 @@ DASPK::error_message (void) const
       break;
 
     case -3:
-      retval = std::string ("error weight became zero during problem. (t = ")
-               + t_curr
-               + "; solution component i vanished, and atol or atol(i) == 0)";
+      retval = "error weight became zero during problem. (t = " + t_curr +
+               "; solution component i vanished, and atol or atol(i) == 0)";
       break;
 
     case -6:
-      retval = std::string ("repeated error test failures on the last attempted step (t = ")
-               + t_curr + ")";
+      retval = "repeated error test failures on the last attempted step (t = "
+               + t_curr + ')';
       break;
 
     case -7:
-      retval = std::string ("the corrector could not converge (t = ")
-               + t_curr + ")";
+      retval = "the corrector could not converge (t = " + t_curr + ')';
       break;
 
     case -8:
-      retval = std::string ("the matrix of partial derivatives is singular (t = ")
-               + t_curr + ")";
+      retval = "the matrix of partial derivatives is singular (t = " + t_curr +
+               ')';
       break;
 
     case -9:
-      retval = std::string ("the corrector could not converge (t = ")
-               + t_curr + "; repeated test failures)";
+      retval = "the corrector could not converge (t = " + t_curr +
+               "; repeated test failures)";
       break;
 
     case -10:
-      retval = std::string ("corrector could not converge because IRES was -1 (t = ")
-               + t_curr + ")";
+      retval = "corrector could not converge because IRES was -1 (t = "
+               + t_curr + ')';
       break;
 
     case -11:
-      retval = std::string ("return requested in user-supplied function (t = ")
-               + t_curr + ")";
+      retval = "return requested in user-supplied function (t = " + t_curr +
+               ')';
       break;
 
     case -12:
@@ -768,13 +765,13 @@ DASPK::error_message (void) const
       break;
 
     case -13:
-      retval = std::string ("unrecoverable error encountered inside user's PSOL function (t = ")
-               + t_curr + ")";
+      retval = "unrecoverable error encountered inside user's PSOL function (t = "
+               + t_curr + ')';
       break;
 
     case -14:
-      retval = std::string ("the Krylov linear system solver failed to converge (t = ")
-               + t_curr + ")";
+      retval = "the Krylov linear system solver failed to converge (t = "
+               + t_curr + ')';
       break;
 
     case -33:
