@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2020 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -210,28 +210,30 @@ octave::string::strncmpi (const T& str_a, const typename T::value_type *str_b,
 
 
 // Instantiations we need
-#define INSTANTIATE_OCTAVE_STRING(T)                                          \
-  template bool octave::string::strcmp<T> (const T&, const T&);               \
-  template bool octave::string::strcmp<T> (const T&,                          \
-                                           const typename T::value_type*);    \
-  template bool octave::string::strcmpi<T> (const T&, const T&);              \
-  template bool octave::string::strcmpi<T> (const T&,                         \
-                                            const typename T::value_type*);   \
-  template bool octave::string::strncmp<T> (const T&, const T&,               \
-                                            const typename T::size_type);     \
-  template bool octave::string::strncmp<T> (const T&,                         \
-                                            const typename T::value_type*,    \
-                                            const typename T::size_type);     \
-  template bool octave::string::strncmpi<T> (const T&, const T&,              \
-                                             const typename T::size_type n);  \
-  template bool octave::string::strncmpi<T> (const T&,                        \
-                                             const typename T::value_type*,   \
-                                             const typename T::size_type);
+#define INSTANTIATE_OCTAVE_STRING(T, API)                                     \
+  template API bool octave::string::strcmp<T> (const T&, const T&);           \
+  template API bool                                                           \
+  octave::string::strcmp<T> (const T&, const typename T::value_type*);        \
+  template API bool octave::string::strcmpi<T> (const T&, const T&);          \
+  template API bool                                                           \
+  octave::string::strcmpi<T> (const T&, const typename T::value_type*);       \
+  template API bool                                                           \
+  octave::string::strncmp<T> (const T&, const T&,                             \
+                              const typename T::size_type);                   \
+  template API bool                                                           \
+  octave::string::strncmp<T> (const T&, const typename T::value_type*,        \
+                              const typename T::size_type);                   \
+  template API bool                                                           \
+  octave::string::strncmpi<T> (const T&, const T&,                            \
+                               const typename T::size_type n);                \
+  template API bool                                                           \
+  octave::string::strncmpi<T> (const T&, const typename T::value_type*,       \
+                               const typename T::size_type);
 
 // We could also instantiate std::vector<char> but would it be
 // useful for anyone?
-INSTANTIATE_OCTAVE_STRING(std::string)
-INSTANTIATE_OCTAVE_STRING(Array<char>)
+INSTANTIATE_OCTAVE_STRING(std::string, OCTAVE_API)
+INSTANTIATE_OCTAVE_STRING(Array<char>, OCTAVE_API)
 
 #undef INSTANTIATE_OCTAVE_STRING
 
@@ -498,9 +500,9 @@ octave::string::u8_to_encoding (const std::string& who,
 {
   const uint8_t *src = reinterpret_cast<const uint8_t *>
                        (u8_string.c_str ());
-  size_t srclen = u8_string.length ();
+  std::size_t srclen = u8_string.length ();
 
-  size_t length;
+  std::size_t length;
   char *native_str = octave_u8_conv_to_encoding (encoding.c_str (), src,
                                                  srclen, &length);
 
@@ -516,8 +518,7 @@ octave::string::u8_to_encoding (const std::string& who,
            who.c_str (), encoding.c_str (), std::strerror (errno));
     }
 
-  octave::unwind_protect frame;
-  frame.add_fcn (::free, static_cast<void *> (native_str));
+  octave::unwind_action free_native_str ([=] () { ::free (native_str); });
 
   std::string retval = std::string (native_str, length);
 
@@ -530,9 +531,9 @@ octave::string::u8_from_encoding (const std::string& who,
                                   const std::string& encoding)
 {
   const char *src = native_string.c_str ();
-  size_t srclen = native_string.length ();
+  std::size_t srclen = native_string.length ();
 
-  size_t length;
+  std::size_t length;
   uint8_t *utf8_str = octave_u8_conv_from_encoding (encoding.c_str (), src,
                                                     srclen, &length);
   if (! utf8_str)
@@ -547,8 +548,7 @@ octave::string::u8_from_encoding (const std::string& who,
            who.c_str (), encoding.c_str (), std::strerror (errno));
     }
 
-  octave::unwind_protect frame;
-  frame.add_fcn (::free, static_cast<void *> (utf8_str));
+  octave::unwind_action free_utf8_str ([=] () { ::free (utf8_str); });
 
   std::string retval = std::string (reinterpret_cast<char *> (utf8_str), length);
 
@@ -565,7 +565,7 @@ octave::string::u8_validate (const std::string& who,
   unsigned int num_replacements = 0;
   const char *in_chr = in_str.c_str ();
   const char *inv_utf8 = in_chr;
-  const char * const in_end = in_chr + in_str.length ();
+  const char *const in_end = in_chr + in_str.length ();
   while (inv_utf8 && in_chr < in_end)
     {
       inv_utf8 = reinterpret_cast<const char *>
@@ -585,7 +585,7 @@ octave::string::u8_validate (const std::string& who,
           else if (type == U8_ISO_8859_1)
             {
               std::string fallback = "iso-8859-1";
-              size_t lengthp;
+              std::size_t lengthp;
               uint8_t *val_utf8 = octave_u8_conv_from_encoding
                                     (fallback.c_str (), inv_utf8, 1, &lengthp);
 
@@ -594,8 +594,8 @@ octave::string::u8_validate (const std::string& who,
                   ("%s: converting from codepage '%s' to UTF-8 failed: %s",
                    who.c_str (), fallback.c_str (), std::strerror (errno));
 
-              octave::unwind_protect frame;
-              frame.add_fcn (::free, static_cast<void *> (val_utf8));
+              octave::unwind_action free_val_utf8
+                ([=] () { ::free (val_utf8); });
 
               out_str.append (reinterpret_cast<const char *> (val_utf8),
                               lengthp);
@@ -616,6 +616,10 @@ rational_approx (T val, int len)
   if (len <= 0)
     len = 10;
 
+  static const T out_of_range_top
+    = static_cast<T>(std::numeric_limits<int>::max ()) + 1.;
+  static const T out_of_range_bottom
+    = static_cast<T>(std::numeric_limits<int>::min ()) - 1.;
   if (octave::math::isinf (val))
     {
       if (val > 0)
@@ -625,8 +629,7 @@ rational_approx (T val, int len)
     }
   else if (octave::math::isnan (val))
     s = "0/0";
-  else if (val < std::numeric_limits<int>::min ()
-           || val > std::numeric_limits<int>::max ()
+  else if (val <= out_of_range_bottom || val >= out_of_range_top
            || octave::math::x_nint (val) == val)
     {
       std::ostringstream buf;
@@ -656,7 +659,7 @@ rational_approx (T val, int len)
           T nextd = d;
 
           // Have we converged to 1/intmax ?
-          if (std::abs (flip) > static_cast<T> (std::numeric_limits<int>::max ()))
+          if (std::abs (flip) > out_of_range_top)
             {
               lastn = n;
               lastd = d;
@@ -687,8 +690,8 @@ rational_approx (T val, int len)
                 break;
             }
 
-          if (std::abs (n) > std::numeric_limits<int>::max ()
-              || std::abs (d) > std::numeric_limits<int>::max ())
+          if (std::abs (n) >= out_of_range_top
+              || std::abs (d) >= out_of_range_top)
             break;
 
           s = buf.str ();
@@ -711,5 +714,5 @@ rational_approx (T val, int len)
 }
 
 // instantiate the template for float and double
-template std::string rational_approx <float> (float val, int len);
-template std::string rational_approx <double> (double val, int len);
+template OCTAVE_API std::string rational_approx <float> (float val, int len);
+template OCTAVE_API std::string rational_approx <double> (double val, int len);
