@@ -1,4 +1,9 @@
-## Copyright (C) 2006-2018 David Bateman
+########################################################################
+##
+## Copyright (C) 2006-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {} atand (@var{x})
@@ -22,11 +29,9 @@
 ## @seealso{tand, atan}
 ## @end deftypefn
 
-## Author: David Bateman <dbateman@free.fr>
-
 function y = atand (x)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -37,5 +42,4 @@ endfunction
 
 %!assert (atand (0:10:90), 180/pi * atan (0:10:90), -10*eps)
 
-%!error atand ()
-%!error atand (1, 2)
+%!error <Invalid call> atand ()
