@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2000-2021 The Octave Project Developers
+## Copyright (C) 2000-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -176,7 +176,7 @@ function t = isequal (x, varargin)
 
       endif
 
-    else  ## More than two args.  This is going to be slower in general.
+    else  # More than two args.  This is going to be slower in general.
 
       if (ischar (x) && all (cellfun ("isclass", varargin, "char")))
         ## char type.  Optimization, strcmp is ~35% faster than '==' operator.
@@ -545,5 +545,5 @@ endfunction
 %!assert (isequal (sparse (1), sparse (1)), sparse (1), true)
 
 ## test input validation
-%!error isequal ()
-%!error isequal (1)
+%!error <Invalid call> isequal ()
+%!error <Invalid call> isequal (1)
