@@ -1,4 +1,9 @@
-## Copyright (C) 2006-2019 Bill Denney
+########################################################################
+##
+## Copyright (C) 2006-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{files} =} unpack (@var{file})
@@ -69,11 +76,9 @@
 ## @seealso{bunzip2, gunzip, unzip, untar, bzip2, gzip, zip, tar}
 ## @end deftypefn
 
-## Author: Bill Denney <denney@seas.upenn.edu>
-
 function filelist = unpack (file, dir = [], filetype = "")
 
-  if (nargin < 1 || nargin > 3)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -88,7 +93,11 @@ function filelist = unpack (file, dir = [], filetype = "")
   if (numel (file) == 1)
     ## FIXME: The code below is not a perfect test for a URL
     if (isempty (strfind (file{1}, "://")))
-      gfile = glob (file);
+      if (ispc ())
+        gfile = __wglob__ (file);
+      else
+        gfile = glob (file);
+      endif
       if (isempty (gfile))
         error ('unpack: FILE "%s" not found', file{1});
       else
@@ -183,12 +192,12 @@ function filelist = unpack (file, dir = [], filetype = "")
   ##    bzip2 and gzip decompress the file at its location).
   persistent commandlist;
   if (isempty (commandlist))
-    commandlist.gz = {'gzip -d -v -f -r "%s"', ...
-                      'gzip -d -f -r "%s"', ...
+    commandlist.gz = {'gzip -d -k -v -f -r "%s"', ...
+                      'gzip -d -k -f -r "%s"', ...
                       @__parse_gzip__, true};
     commandlist.z = commandlist.gz;
-    commandlist.bz2 = {'bzip2 -d -v -f "%s"', ...
-                       'bzip2 -d -f "%s"', ...
+    commandlist.bz2 = {'bzip2 -d -k -v -f "%s"', ...
+                       'bzip2 -d -k -f "%s"', ...
                        @__parse_bzip2__, true};
     commandlist.bz = commandlist.bz2;
     commandlist.tar = {'tar xvf "%s"', ...
@@ -221,6 +230,17 @@ function filelist = unpack (file, dir = [], filetype = "")
     file = __w2mpth__ (file);
   endif
 
+  ## Create the output directory if necessary.
+  s = stat (dir);
+  if (isempty (s))
+    [status, msg] = mkdir (dir);
+    if (! status)
+      error ("unpack: mkdir failed to create %s: %s", dir, msg);
+    endif
+  elseif (! S_ISDIR (s.mode))
+    error ("unpack: %s: not a directory", dir);
+  endif
+
   if (isfield (commandlist, tolower (nodotext)))
     [commandv, commandq, parsefcn, move] = deal (commandlist.(nodotext){:});
     origdir = pwd ();
@@ -234,7 +254,7 @@ function filelist = unpack (file, dir = [], filetype = "")
     if (cenddir(end) == filesep)
       cenddir(end) = [];
     endif
-    needmove = move && ! strcmp (cstartdir, cenddir);
+    needmove = move && ! is_same_file (cstartdir, cenddir);
     if (nargout > 0 || needmove)
       command = commandv;
     else
@@ -246,17 +266,6 @@ function filelist = unpack (file, dir = [], filetype = "")
     return;
   endif
 
-  ## Create the directory if necessary.
-  s = stat (dir);
-  if (isempty (s))
-    [status, msg] = mkdir (dir);
-    if (! status)
-      error ("unpack: mkdir failed to create %s: %s", dir, msg);
-    endif
-  elseif (! S_ISDIR (s.mode))
-    error ("unpack: %s: not a directory", dir);
-  endif
-
   ## Save and restore the TAR_OPTIONS environment variable used by GNU tar.
   tar_options_env = getenv ("TAR_OPTIONS");
   unwind_protect
@@ -308,14 +317,18 @@ function files = __parse_zip__ (output)
 endfunction
 
 function output = __parse_tar__ (output)
-  ## This is a no-op, but it makes things simpler for other cases.
+  ## BSD tar emits file actions in the first 2 columns
+
+  if (tar_is_bsd ())
+    output = cellfun (@(x) x(3:end), output, 'UniformOutput', false);
+  endif
 endfunction
 
 function files = __parse_gzip__ (output)
   ## Parse the output from gzip and gunzip returning the files
   ## compressed (or decompressed).
 
-  files = regexprep (output, '^.+ -- replaced with (.*)$', '$1');
+  files = regexprep (output, '^.+ -- (?:created|replaced with) (.*)$', '$1');
 endfunction
 
 function files = __parse_bzip2__ (output)
@@ -363,7 +376,7 @@ endfunction
 %!     unlink (filename);
 %!     unlink ([filename ".orig"]);
 %!     confirm_recursive_rmdir (false, "local");
-%!     rmdir (dirname, "s");
+%!     sts = rmdir (dirname, "s");
 %!   end_unwind_protect
 %! unwind_protect_cleanup
 %!   ## Restore environment variables TMPDIR, TMP
@@ -377,8 +390,7 @@ endfunction
 %! end_unwind_protect
 
 ## Test input validation
-%!error unpack ()
-%!error unpack (1,2,3,4)
+%!error <Invalid call> unpack ()
 %!error <FILE must be a string or cell array of strings> unpack (1)
 %!error <FILE "_%NOT_A_FILENAME%_" not found> unpack ("_%NOT_A_FILENAME%_")
 %!error <FILE "_%NOT_A_FILENAME%_" not found> unpack ({"_%NOT_A_FILENAME%_"})
